@@ -22,7 +22,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: page-info-dialog.c,v 1.38 2005/01/13 16:15:48 chpe Exp $
+ *  $Id: page-info-dialog.c,v 1.40 2005/02/11 15:44:02 chpe Exp $
  */
 
 #include "config.h"
@@ -625,7 +625,7 @@ general_info_page_fill (InfoPage *page)
 	struct tm tm;
 	time_t t;
 
-	LOG ("general_info_page_fill")
+	LOG ("general_info_page_fill");
 
 	props = dialog->priv->page_info->props;
 	g_return_if_fail (props != NULL);
@@ -655,6 +655,7 @@ general_info_page_fill (InfoPage *page)
 		case EMBED_RENDER_QUIRKS:
 			text = _("Compatibility");
 			break;
+		case EMBED_RENDER_UNKNOWN:
 		default:
 			text = _("Undetermined");
 			break;
@@ -1879,7 +1880,7 @@ page_info_dialog_finalize (GObject *object)
 	PageInfoDialog *dialog = PAGE_INFO_DIALOG (object);
 	int i;
 
-	LOG ("PageInfoDialog finalizing")
+	LOG ("PageInfoDialog finalizing");
 
 	mozilla_free_embed_page_info (dialog->priv->page_info);
 	for (i = GENERAL_PAGE; i < LAST_PAGE; i++)
